@@ -1,10 +1,9 @@
 '''
 Cohort group class
 '''
+import pandas as pd
 from .cohort_member import CohortMember
-from .student import Student
 from .base import Base
-from .utils import Utils
 
 
 class CohortGroup(Base):
@@ -17,7 +16,7 @@ class CohortGroup(Base):
     name_of_class = "cohort-groups"
 
     def __repr__(self):
-        return super().__repr__(['cohort','name'])
+        return super().__repr__(['_id','name'])
 
     def add_single_member(self, member, status='participant'):
         '''
@@ -31,35 +30,36 @@ class CohortGroup(Base):
             print('ERROR: Data must be instance of Cohort Member')
             return
         if not getattr(self, '_id', ''):
-            print('ERROR: Cohort Group undefined')
+            print('ERROR: Missing cohort group ID')
             return
         if not getattr(member, '_id', ''):
-            print('ERROR: Cohort Member undefined')
+            print('ERROR: Missing Cohort Member ID')
             return
         member.cohort_group_id = self._id
-        member.save(self.db_service)
+        member.save()
 
-    def add_members_to_group(self, members):
+    def add_members(self, members):
         '''
         Add a list of members to the cohort group
         Parameter:
-            db_service: DBService object indicate the server to put on
             members: a list of cohort members (each cohort member is in CohortMember type)
         '''
         for member in members:
-            self.add_single_member(self.db_service, member)
+            self.add_single_member(member)
 
-    def get_student_list(self, output='DataFrame'):
+    def get_member_list(self):
         '''
-        Get student information in the current cohort group from database
-        Parameter:
-            db_service: DBService object indicate the server to put on
-            output: kind of multi-value class to holder the result. the default is 'DataFrame'
-        Return: result in corresponding output type, each single item is in Student object type
+        Get member information in the current cohort group from database
+
+        Return: a pandas DataFrame of members who are in the cohort group
         '''
         if not getattr(self, '_id', ''):
             print('ERROR: Cohort Group undefined')
             return
-        students = (self.db_service.get(f'/cohort-groups/{self._id}/students')
-                    ['students'])
-        return Utils.output_form(Student, students, output)
+        from_server = self.db_service.get(f'/cohort-groups/{self._id}/members')
+        try:
+            rows = pd.DataFrame(from_server['members']) if from_server['members'] else []
+            total = from_server['totalNumber']
+            return rows, total
+        except:
+            return [], 0
