@@ -1,4 +1,4 @@
-ENVIRONMENT = 'PRODUCTION'
+ENVIRONMENT = 'LOCAL'
 base_urls = {
   'MVP': 'https://cs-platform-306304.et.r.appspot.com/api',
   'STAGING': 'https://staging-dot-cs-platform-306304.et.r.appspot.com/api/v1',
